@@ -1,4 +1,5 @@
 import speech_recognition as sr
+import os
 from .mute_shell import mute_on, mute_off
 def recognize_speech_from_mic(recognizer, microphone):
     with microphone as source:
@@ -24,9 +25,9 @@ def recognize_speech_from_mic(recognizer, microphone):
 def voice():
 
     recognizer = sr.Recognizer()
-    mute_on()
+    if os.name!='nt': mute_on()
     microphone = sr.Microphone()
-    mute_off()
+    if os.name!='nt': mute_off()
     print('Listening... (Press "Ctrl+C" to cancel)')
     voice_text = recognize_speech_from_mic(recognizer, microphone)
     if voice_text["transcription"]:
